@@ -215,7 +215,7 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		print procStdOut
 		if rc:
 			print procStdErr
-		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, name, description)	
+		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
 		hubzero.utilities.group._insert_jos_xgroups_members(gidNumber, userID)
 		
 
